NLSL: mtsdef.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
mtsdef.f90 File Reference

Go to the source code of this file.

## Modules
module | mtsdef

## Variables
integer, parameter | mtsdef::nlemx =1
integer, parameter | mtsdef::nlomx =2
integer, parameter | mtsdef::nkmn =3
integer, parameter | mtsdef::nkmx =4
integer, parameter | mtsdef::nmmn =5
integer, parameter | mtsdef::nmmx =6
integer, parameter | mtsdef::nipnmx =7
integer, parameter | mtsdef::nldel =8
integer, parameter | mtsdef::nkdel =9
integer, parameter | mtsdef::nipsi0 =10
integer, parameter | mtsdef::nin2 =11
integer, parameter | mtsdef::njkmn =12
integer, parameter | mtsdef::njmmn =13
integer, parameter | mtsdef::ntrc =7